@@ -122,7 +122,7 @@ public:
     void deleteFileUsingJob(const QUrl &url, bool isLink);
     void deleteDirUsingJob(const QUrl &url);
 
-    ~DeleteJobPrivate();
+    ~DeleteJobPrivate() override;
 
     Q_DECLARE_PUBLIC(DeleteJob)
 
@@ -325,9 +325,8 @@ void DeleteJobPrivate::finishedStatPhase()
     // To speed things up and prevent double-notification, we disable KDirWatch
     // on those dirs temporarily (using KDirWatch::self, that's the instance
     // used by e.g. kdirlister).
-    const QSet<QString>::const_iterator itEnd = m_parentDirs.constEnd();
-    for (QSet<QString>::const_iterator it = m_parentDirs.constBegin(); it != itEnd; ++it) {
-        KDirWatch::self()->stopDirScan(*it);
+    for (const QString &dir : std::as_const(m_parentDirs)) {
+        KDirWatch::self()->stopDirScan(dir);
     }
     state = DELETEJOB_STATE_DELETING_FILES;
     deleteNextFile();
@@ -455,7 +454,9 @@ void DeleteJobPrivate::deleteNextDir()
     // Finished - tell the world
     if (!m_srcList.isEmpty()) {
         // qDebug() << "KDirNotify'ing FilesRemoved" << m_srcList;
+#ifndef KIO_ANDROID_STUB
         org::kde::KDirNotify::emitFilesRemoved(m_srcList);
+#endif
     }
     if (m_reportTimer != nullptr) {
         m_reportTimer->stop();
