@@ -7,10 +7,9 @@
     SPDX-License-Identifier: LGPL-2.0-only
 */
 
-#include "kprotocolinfofactory_p.h"
 #include "kprotocolinfo_p.h"
+#include "kprotocolinfofactory_p.h"
 
-#include <KPluginLoader>
 #include <KPluginMetaData>
 
 #include <QCoreApplication>
@@ -92,7 +91,7 @@ bool KProtocolInfoFactory::fillCache()
 
     // first: search for meta data protocol info, that might be bundled with applications
     // we search in all library paths inside kf5/kio
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("kf5/kio"));
+    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("kf5/kio"));
     for (const KPluginMetaData &md : plugins) {
         // get slave name & protocols it supports, if any
         const QString slavePath = md.fileName();
@@ -114,8 +113,10 @@ bool KProtocolInfoFactory::fillCache()
         }
     }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 84)
     // second: fallback to .protocol files
-    const QStringList serviceDirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("kservices5"), QStandardPaths::LocateDirectory)
+    const QStringList serviceDirs =
+        QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("kservices5"), QStandardPaths::LocateDirectory)
         << QCoreApplication::applicationDirPath() + QLatin1String("/kservices5");
     for (const QString &serviceDir : serviceDirs) {
         QDirIterator it(serviceDir);
@@ -125,11 +126,13 @@ bool KProtocolInfoFactory::fillCache()
                 const QString prot = it.fileInfo().baseName();
                 // add to cache, skip double entries
                 if (!m_cache.contains(prot)) {
+                    qCDebug(KIO_CORE) << "Loading deprecated protocol file, please port it to JSON metadata" << file;
                     m_cache.insert(prot, new KProtocolInfoPrivate(file));
                 }
             }
         }
     }
+#endif
 
     // all done, don't do it again
     m_cacheDirty = false;
