@@ -22,6 +22,7 @@
 #include <KServiceTypeTrader>
 #include <kapplicationtrader.h>
 #include <kdesktopfileactions.h>
+#include <kdirnotify.h>
 #include <kurlauthorized.h>
 
 #include <QFile>
@@ -29,10 +30,12 @@
 #include <QMimeDatabase>
 #include <QtAlgorithms>
 
+#ifndef KIO_ANDROID_STUB
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDBusInterface>
 #include <QDBusMessage>
+#endif
 #include <algorithm>
 #include <kio_widgets_debug.h>
 
@@ -47,29 +50,24 @@ static bool KIOSKAuthorizedAction(const KConfigGroup &cfg)
 static bool mimeTypeListContains(const QStringList &list, const KFileItem &item)
 {
     const QString itemMimeType = item.mimetype();
-    return std::any_of(list.constBegin(), list.constEnd(), [itemMimeType, item](const QString &i) {
-        if (i == itemMimeType || i == QLatin1String("all/all")) {
-            return true;
-        }
-        if (item.isFile() && (i == QLatin1String("allfiles") || i == QLatin1String("all/allfiles") || i == QLatin1String("application/octet-stream"))) {
+    return std::any_of(list.cbegin(), list.cend(), [&](const QString &mt) {
+        if (mt == itemMimeType || mt == QLatin1String("all/all")) {
             return true;
         }
 
-        if (item.currentMimeType().inherits(i)) {
+        if (item.isFile() //
+            && (mt == QLatin1String("allfiles") || mt == QLatin1String("all/allfiles") || mt == QLatin1String("application/octet-stream"))) {
             return true;
         }
 
-        const int iSlashPos = i.indexOf(QLatin1Char(QLatin1Char('/')));
-        Q_ASSERT(iSlashPos > 0);
-        const QStringRef iSubType = i.midRef(iSlashPos + 1);
+        if (item.currentMimeType().inherits(mt)) {
+            return true;
+        }
 
-        if (iSubType == QLatin1String("*")) {
-            const int itemSlashPos = itemMimeType.indexOf(QLatin1Char('/'));
-            Q_ASSERT(itemSlashPos > 0);
-            const QStringRef iTopLevelType = i.midRef(0, iSlashPos);
-            const QStringRef itemTopLevelType = itemMimeType.midRef(0, itemSlashPos);
-
-            return itemTopLevelType == iTopLevelType;
+        if (mt.endsWith(QLatin1String("/*"))) {
+            const int slashPos = mt.indexOf(QLatin1Char('/'));
+            const auto topLevelType = QStringView(mt).mid(0, slashPos);
+            return itemMimeType.startsWith(topLevelType);
         }
         return false;
     });
@@ -159,8 +157,12 @@ int KFileItemActionsPrivate::insertServicesSubmenus(const QMap<QString, ServiceL
 
 int KFileItemActionsPrivate::insertServices(const ServiceList &list, QMenu *menu, bool isBuiltin)
 {
+    ServiceList sortedList = list;
+    std::sort(sortedList.begin(), sortedList.end(), [](const KServiceAction &a1, const KServiceAction &a2) {
+        return a1.name() < a2.name();
+    });
     int count = 0;
-    for (const KServiceAction &serviceAction : list) {
+    for (const KServiceAction &serviceAction : std::as_const(sortedList)) {
         if (serviceAction.isSeparator()) {
             const QList<QAction *> actions = menu->actions();
             if (!actions.isEmpty() && !actions.last()->isSeparator()) {
@@ -193,7 +195,10 @@ void KFileItemActionsPrivate::slotExecuteService(QAction *act)
 {
     const KServiceAction serviceAction = act->data().value<KServiceAction>();
     if (KAuthorized::authorizeAction(serviceAction.name())) {
-        KDesktopFileActions::executeService(m_props.urlList(), serviceAction);
+        auto *job = new KIO::ApplicationLauncherJob(serviceAction);
+        job->setUrls(m_props.urlList());
+        job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
+        job->start();
     }
 }
 
@@ -439,7 +444,7 @@ bool KFileItemActionsPrivate::shouldDisplayServiceMenu(const KConfigGroup &cfg,
     if (!KIOSKAuthorizedAction(cfg)) {
         return false;
     }
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 76)
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 76) && !defined(KIO_ANDROID_STUB)
     if (cfg.hasKey("X-KDE-ShowIfRunning")) {
         qCWarning(KIO_WIDGETS) << "The property X-KDE-ShowIfRunning is deprecated and will be removed in future releases";
         const QString app = cfg.readEntry("X-KDE-ShowIfRunning");
@@ -469,9 +474,8 @@ bool KFileItemActionsPrivate::shouldDisplayServiceMenu(const KConfigGroup &cfg,
 #endif
     if (cfg.hasKey("X-KDE-Protocol")) {
         const QString theProtocol = cfg.readEntry("X-KDE-Protocol");
-        if (theProtocol.startsWith(QLatin1Char('!'))) {
-            const QStringRef excludedProtocol = theProtocol.midRef(1);
-            if (excludedProtocol == protocol) {
+        if (theProtocol.startsWith(QLatin1Char('!'))) { // Is it excluded?
+            if (QStringView(theProtocol).mid(1) == protocol) {
                 return false;
             }
         } else if (protocol != theProtocol) {
@@ -559,7 +563,7 @@ QPair<int, QMenu *> KFileItemActionsPrivate::addServiceActionsTo(QMenu *mainMenu
         const QString priority = cfg.readEntry("X-KDE-Priority");
         const QString submenuName = cfg.readEntry("X-KDE-Submenu");
         ServiceList &list = s.selectList(priority, submenuName);
-        list = KDesktopFileActions::userDefinedServices(path, desktopFile, true /*isLocal*/);
+        list = KDesktopFileActions::userDefinedServices(KService(path), true /*isLocal*/);
     }
 
     // 2 - Look for "servicemenus" bindings (user-defined services)
@@ -575,7 +579,7 @@ QPair<int, QMenu *> KFileItemActionsPrivate::addServiceActionsTo(QMenu *mainMenu
                 const QString priority = cfg.readEntry("X-KDE-Priority");
                 const QString submenuName = cfg.readEntry("X-KDE-Submenu");
                 ServiceList &list = s.selectList(priority, submenuName);
-                list += KDesktopFileActions::userDefinedServices(dotDirectoryFile, desktopFile, true);
+                list += KDesktopFileActions::userDefinedServices(KService(dotDirectoryFile), true);
             }
         }
     }
@@ -601,7 +605,7 @@ QPair<int, QMenu *> KFileItemActionsPrivate::addServiceActionsTo(QMenu *mainMenu
             const QString submenuName = cfg.readEntry("X-KDE-Submenu");
 
             ServiceList &list = s.selectList(priority, submenuName);
-            const ServiceList userServices = KDesktopFileActions::userDefinedServices(file, desktopFile, isLocal, urlList);
+            const ServiceList userServices = KDesktopFileActions::userDefinedServices(KService(file), isLocal, urlList);
             for (const KServiceAction &action : userServices) {
                 if (showGroup.readEntry(action.name(), true) && !excludeList.contains(action.name())) {
                     list += action;
@@ -652,7 +656,7 @@ int KFileItemActionsPrivate::addPluginActionsTo(QMenu *mainMenu, QMenu *actionsM
     const KConfigGroup showGroup = m_config.group("Show");
 
     const QMimeDatabase db;
-    const auto jsonPlugins = KPluginLoader::findPlugins(QStringLiteral("kf5/kfileitemaction"), [&db, commonMimeType](const KPluginMetaData &metaData) {
+    const auto jsonPlugins = KPluginMetaData::findPlugins(QStringLiteral("kf5/kfileitemaction"), [&db, commonMimeType](const KPluginMetaData &metaData) {
         auto mimeType = db.mimeTypeForName(commonMimeType);
         const QStringList list = metaData.mimeTypes();
         return std::any_of(list.constBegin(), list.constEnd(), [mimeType](const QString &supportedMimeType) {
@@ -667,13 +671,9 @@ int KFileItemActionsPrivate::addPluginActionsTo(QMenu *mainMenu, QMenu *actionsM
             continue;
         }
 
-        KPluginFactory *factory = KPluginLoader(jsonMetadata.fileName()).factory();
-        if (!factory) {
-            continue;
-        }
         KAbstractFileItemActionPlugin *abstractPlugin = m_loadedPlugins.value(pluginId);
         if (!abstractPlugin) {
-            abstractPlugin = factory->create<KAbstractFileItemActionPlugin>(this);
+            abstractPlugin = KPluginFactory::instantiatePlugin<KAbstractFileItemActionPlugin>(jsonMetadata, this).plugin;
             m_loadedPlugins.insert(pluginId, abstractPlugin);
         }
         if (abstractPlugin) {
@@ -818,7 +818,7 @@ KFileItemActionsPrivate::associatedApplications(const QStringList &mimeTypeList,
 
     KService::List result;
     result.reserve(rankings.size());
-    for (const KFileItemActionsPrivate::ServiceRank &tempRank : qAsConst(rankings)) {
+    for (const KFileItemActionsPrivate::ServiceRank &tempRank : std::as_const(rankings)) {
         result << tempRank.service;
     }
 
@@ -900,7 +900,7 @@ void KFileItemActionsPrivate::insertOpenWithActionsTo(QAction *before,
             subMenu->setIcon(QIcon::fromTheme(QStringLiteral("system-run")));
             subMenu->menuAction()->setObjectName(QStringLiteral("openWith_submenu")); // For the unittest
             // Add other apps to the sub-menu
-            for (const KServicePtr &service : qAsConst(offers)) {
+            for (const KServicePtr &service : std::as_const(offers)) {
                 QAction *act = createAppAction(service, false);
                 subMenu->addAction(act);
             }
