@@ -362,15 +362,15 @@ QString KFileItemDelegate::Private::elidedText(QTextLayout &layout, const QStyle
 
     for (int i = 0; i < layout.lineCount(); i++) {
         QTextLine line = layout.lineAt(i);
-        int start = line.textStart();
-        int length = line.textLength();
+        const int start = line.textStart();
+        const int length = line.textLength();
 
         height += option.fontMetrics.leading();
         if (height + line.height() + option.fontMetrics.lineSpacing() > maxHeight) {
             // Unfortunately, if the line ends because of a line separator, elidedText() will be too
             // clever and keep adding lines until it finds one that's too wide.
             if (line.naturalTextWidth() < maxWidth && text[start + length - 1] == QChar::LineSeparator) {
-                elided += text.midRef(start, length - 1);
+                elided += QStringView(text).mid(start, length - 1);
             } else {
                 elided += option.fontMetrics.elidedText(text.mid(start), option.textElideMode, maxWidth);
             }
@@ -381,7 +381,7 @@ QString KFileItemDelegate::Private::elidedText(QTextLayout &layout, const QStyle
                 elided += QChar::LineSeparator;
             }
         } else {
-            elided += text.midRef(start, length);
+            elided += QStringView(text).mid(start, length);
         }
 
         height += line.height();
@@ -1205,7 +1205,8 @@ void KFileItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
     //### Apply the selection effect to the icon when the item is selected and
     //     showDecorationSelected is false.
 
-    QTextLayout labelLayout, infoLayout;
+    QTextLayout labelLayout;
+    QTextLayout infoLayout;
     QRect textBoundingRect;
 
     d->layoutTextItems(opt, index, &labelLayout, &infoLayout, &textBoundingRect);
