@@ -321,17 +321,15 @@ void PreviewJobPrivate::startPreview()
 
     // Look for images and store the items in our todo list :)
     bool bNeedCache = false;
-    KFileItemList::const_iterator kit = initialItems.constBegin();
-    const KFileItemList::const_iterator kend = initialItems.constEnd();
-    for (; kit != kend; ++kit) {
+    for (const auto &fileItem : std::as_const(initialItems)) {
         PreviewItem item;
-        item.item = *kit;
+        item.item = fileItem;
 
         const QString mimeType = item.item.mimetype();
         KService::Ptr plugin(nullptr);
 
         // look for protocol-specific thumbnail plugins first
-        QHash<QString, QHash<QString, KService::Ptr>>::const_iterator it = protocolMap.constFind(item.item.url().scheme());
+        auto it = protocolMap.constFind(item.item.url().scheme());
         if (it != protocolMap.constEnd()) {
             plugin = it.value().value(mimeType);
         }
@@ -368,13 +366,13 @@ void PreviewJobPrivate::startPreview()
             item.plugin = plugin;
             items.push_back(item);
             if (!bNeedCache && bSave && plugin->property(QStringLiteral("CacheThumbnail")).toBool()) {
-                const QUrl url = (*kit).url();
+                const QUrl url = fileItem.url();
                 if (!url.isLocalFile() || !url.adjusted(QUrl::RemoveFilename).toLocalFile().startsWith(thumbRoot)) {
                     bNeedCache = true;
                 }
             }
         } else {
-            Q_EMIT q->failed(*kit);
+            Q_EMIT q->failed(fileItem);
         }
     }
 
@@ -434,13 +432,11 @@ void PreviewJob::removeItem(const QUrl &url)
 {
     Q_D(PreviewJob);
 
-    auto it = d->items.cbegin();
-    while (it != d->items.cend()) {
-        if ((*it).item.url() == url) {
-            d->items.erase(it);
-            break;
-        }
-        ++it;
+    auto it = std::find_if(d->items.cbegin(), d->items.cend(), [&url](const PreviewItem &pItem) {
+        return url == pItem.item.url();
+    });
+    if (it != d->items.cend()) {
+        d->items.erase(it);
     }
 
     if (d->currentItem.item.url() == url) {
